# Changelog

## 1.1.3 2024-12-11

* Fix: path urlencoding for compatibility with new music server version

## 1.1.2 2024-11-27

* Improve: compatibility with Python 3.11

## 1.1.1 2024-11-27

* Fix: lyrics always returning plain even when time synced lyrics are available
* Fix: error when close() is called before setup()

## 1.1.0 2024-11-24

* New: client for headless music player

## 1.0.0 2024-11-23

Initial release
